==> beast-0.6.0.tar.gz: beast-0.6.0/bse/bseenums.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bseenums.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bseenums.h>


#line 26 "bseenums.proc"


/* --- bse-error-name --- */
static void
bse_error_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 28 "bseenums.proc"
 {
#line 30 "bseenums.proc"
  *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
  *(out_pspecs++) = sfi_pspec_string ("name", "Name", NULL,
			    NULL, SFI_PARAM_STANDARD);
#line 35 "bseenums.proc"
}  }
static BseErrorType
#line 35 "bseenums.proc"
bse_error_name_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 38 "bseenums.proc"
{
#line 39 "bseenums.proc"
  
  BseErrorType error = g_value_get_enum (in_values++);
  
#line 42 "bseenums.proc"
  
  
#line 44 "bseenums.proc"
  
  
#line 46 "bseenums.proc"
  
  g_value_set_string (out_values++, bse_error_name (error));
  
  return BSE_ERROR_NONE;
}

/* --- bse-error-blurb --- */
static void
bse_error_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 52 "bseenums.proc"
 {
#line 54 "bseenums.proc"
  *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
  *(out_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
			    NULL, SFI_PARAM_STANDARD);
#line 59 "bseenums.proc"
}  }
static BseErrorType
#line 59 "bseenums.proc"
bse_error_blurb_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 62 "bseenums.proc"
{
#line 63 "bseenums.proc"
  
  BseErrorType error = g_value_get_enum (in_values++);
  
#line 66 "bseenums.proc"
  
  
#line 68 "bseenums.proc"
  
  
#line 70 "bseenums.proc"
  
  g_value_set_string (out_values++, bse_error_blurb (error));
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_bse_error_name = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "bse-error-name", 
    NULL,
    "/Proc/Error Name",
    "Retrieve the name of an error value",
    "Tim Janik <timj@gtk.org>",
    "GNU Lesser General Public License",
  },
  0, bse_error_name_setup, bse_error_name_exec, 
};
static BseExportNodeProc __enode_bse_error_blurb = {
  { (BseExportNode*) &__enode_bse_error_name, BSE_EXPORT_NODE_PROC,
    "bse-error-blurb", 
    NULL,
    "/Proc/Error Blurb",
    "Retrieve the description of an error value",
    "Tim Janik <timj@gtk.org>",
    "GNU Lesser General Public License",
  },
  0, bse_error_blurb_setup, bse_error_blurb_exec, 
};
BseExportNode* bse__builtin_init_bseenums_gen_proc_c (void);
BseExportNode* bse__builtin_init_bseenums_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_error_blurb;
}

/**
 ** Generated data ends here
 **/

==> beast_0.6.2.orig.tar.gz: beast-0.6.2/bse/bseenums.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bseenums.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bseenums.h>


#line 26 "bseenums.proc"


/* --- bse-error-name --- */
static void
bse_error_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 28 "bseenums.proc"
 {
#line 30 "bseenums.proc"
  *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
  *(out_pspecs++) = sfi_pspec_string ("name", "Name", NULL,
			    NULL, SFI_PARAM_STANDARD);
#line 35 "bseenums.proc"
}  }
static BseErrorType
#line 35 "bseenums.proc"
bse_error_name_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 38 "bseenums.proc"
{
#line 39 "bseenums.proc"
  
  BseErrorType error = g_value_get_enum (in_values++);
  
#line 42 "bseenums.proc"
  
  
#line 44 "bseenums.proc"
  
  
#line 46 "bseenums.proc"
  
  g_value_set_string (out_values++, bse_error_name (error));
  
  return BSE_ERROR_NONE;
}

/* --- bse-error-blurb --- */
static void
bse_error_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 52 "bseenums.proc"
 {
#line 54 "bseenums.proc"
  *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
  *(out_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
			    NULL, SFI_PARAM_STANDARD);
#line 59 "bseenums.proc"
}  }
static BseErrorType
#line 59 "bseenums.proc"
bse_error_blurb_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 62 "bseenums.proc"
{
#line 63 "bseenums.proc"
  
  BseErrorType error = g_value_get_enum (in_values++);
  
#line 66 "bseenums.proc"
  
  
#line 68 "bseenums.proc"
  
  
#line 70 "bseenums.proc"
  
  g_value_set_string (out_values++, bse_error_blurb (error));
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static void
__enode_bse_error_name__fill_strings (BseExportStrings *es)
{
  es->blurb = "Retrieve the name of an error value";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU Lesser General Public License";
}
static BseExportNodeProc __enode_bse_error_name = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "bse-error-name", 
    NULL,
    "/Proc/Error Name",
    NULL,
    __enode_bse_error_name__fill_strings,
  },
  0, bse_error_name_setup, bse_error_name_exec, 
};
static void
__enode_bse_error_blurb__fill_strings (BseExportStrings *es)
{
  es->blurb = "Retrieve the description of an error value";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU Lesser General Public License";
}
static BseExportNodeProc __enode_bse_error_blurb = {
  { (BseExportNode*) &__enode_bse_error_name, BSE_EXPORT_NODE_PROC,
    "bse-error-blurb", 
    NULL,
    "/Proc/Error Blurb",
    NULL,
    __enode_bse_error_blurb__fill_strings,
  },
  0, bse_error_blurb_setup, bse_error_blurb_exec, 
};
BseExportNode* bse__builtin_init_bseenums_gen_proc_c (void);
BseExportNode* bse__builtin_init_bseenums_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_error_blurb;
}

/**
 ** Generated data ends here
 **/
